@@ -1,7 +1,7 @@
 #ifndef IMV_BINDS_H
 #define IMV_BINDS_H
 
-#include <SDL2/SDL.h>
+#include <unistd.h>
 
 struct imv_binds;
 struct list;
@@ -25,6 +25,9 @@ enum bind_result imv_binds_add(struct imv_binds *binds, const struct list *keys,
 /* Remove all key bindings */
 void imv_binds_clear(struct imv_binds *binds);
 
+/* Clear all bindings for a key*/
+void imv_binds_clear_key(struct imv_binds *binds, const struct list *keys);
+
 /* Fetch the list of keys pressed so far */
 const struct list *imv_bind_input_buffer(struct imv_binds *binds);
 
@@ -32,7 +35,7 @@ const struct list *imv_bind_input_buffer(struct imv_binds *binds);
 void imv_bind_clear_input(struct imv_binds *binds);
 
 /* Handle an input event, if a bind is triggered, return its command */
-const char *imv_bind_handle_event(struct imv_binds *binds, const SDL_Event *event);
+struct list *imv_bind_handle_event(struct imv_binds *binds, const char *event);
 
 /* Convert a string (such as from a config) to a key list */
 struct list *imv_bind_parse_keys(const char *keys);
